@@ -61,6 +61,9 @@ initialize_gui(CelluloidApplication *app);
 static void
 create_dirs(void);
 
+static void
+set_lua_path(void);
+
 static gboolean
 shutdown_signal_handler(gpointer data);
 
@@ -91,9 +94,6 @@ command_line_handler(	GApplication *gapp,
 static void
 startup_handler(GApplication *gapp, gpointer data);
 
-static void
-idle_handler(GObject *object, GParamSpec *pspec, gpointer data);
-
 static void
 shutdown_handler(CelluloidController *controller, gpointer data);
 
@@ -179,10 +179,6 @@ initialize_gui(CelluloidApplication *app)
 	g_unix_signal_add(SIGTERM, shutdown_signal_handler, app);
 #endif
 
-	g_signal_connect(	controller,
-				"notify::idle",
-				G_CALLBACK(idle_handler),
-				app );
 	g_signal_connect(	controller,
 				"shutdown",
 				G_CALLBACK(shutdown_handler),
@@ -198,11 +194,6 @@ initialize_gui(CelluloidApplication *app)
 				celluloid_view_get_main_window(view),
 				"always-use-floating-controls",
 				G_SETTINGS_BIND_GET );
-	g_settings_bind(	settings,
-				"always-use-floating-header-bar",
-				celluloid_view_get_main_window(view),
-				"always-use-floating-header-bar",
-				G_SETTINGS_BIND_GET );
 	g_settings_bind(	settings,
 				"dark-theme-enable",
 				controller,
@@ -229,6 +220,30 @@ create_dirs()
 	g_free(watch_dir);
 }
 
+static void
+set_lua_path()
+{
+	const gchar *old_lua_path = g_getenv("LUA_PATH");
+	gchar *new_lua_path = NULL;
+	gchar *modules = get_script_modules_dir_path();
+
+	if(old_lua_path)
+	{
+		new_lua_path =
+			g_strdup_printf("%s/?.lua;%s", modules, old_lua_path);
+	}
+	else
+	{
+		new_lua_path =
+			g_strdup_printf("%s/?.lua;;", modules);
+	}
+
+	g_setenv("LUA_PATH", new_lua_path, TRUE);
+
+	g_free(modules);
+	g_free(new_lua_path);
+}
+
 static gboolean
 shutdown_signal_handler(gpointer data)
 {
@@ -462,56 +477,12 @@ startup_handler(GApplication *gapp, gpointer data)
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 	create_dirs();
+	set_lua_path();
+
 
 	g_info("Starting Celluloid " VERSION);
 }
 
-static void
-idle_handler(GObject *object, GParamSpec *pspec, gpointer data)
-{
-	GSettings *settings = g_settings_new(CONFIG_ROOT);
-	CelluloidApplication *app = data;
-	CelluloidController *controller = NULL;
-	gboolean idle = TRUE;
-
-	for(	GSList *iter = app->controllers;
-		iter && idle;
-		iter = g_slist_next(iter) )
-	{
-		gboolean current = TRUE;
-
-		g_object_get(iter->data, "idle", &current, NULL);
-		idle &= current;
-		controller = iter->data;
-	}
-
-	if(	!idle &&
-		app->inhibit_cookie == 0 &&
-		g_settings_get_boolean(settings, "inhibit-idle") )
-	{
-		CelluloidView *view =
-			celluloid_controller_get_view(controller);
-		CelluloidMainWindow *window =
-			celluloid_view_get_main_window(view);
-
-		app->inhibit_cookie
-			= gtk_application_inhibit
-				(	GTK_APPLICATION(app),
-					GTK_WINDOW(window),
-					GTK_APPLICATION_INHIBIT_IDLE,
-					_("Playing") );
-	}
-	else if(idle && app->inhibit_cookie != 0)
-	{
-		gtk_application_uninhibit
-			(GTK_APPLICATION(app), app->inhibit_cookie);
-
-		app->inhibit_cookie = 0;
-	}
-
-	g_object_unref(settings);
-}
-
 static void
 shutdown_handler(CelluloidController *controller, gpointer data)
 {
@@ -544,7 +515,6 @@ celluloid_application_init(CelluloidApplication *app)
 	app->new_window = FALSE;
 	app->mpv_options = NULL;
 	app->role = NULL;
-	app->inhibit_cookie = 0;
 
 	g_set_prgname(APP_ID);
 	g_action_map_add_action(G_ACTION_MAP(app), G_ACTION(new_window));
