@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2023 gnome-mpv
+ * Copyright (c) 2014-2024 gnome-mpv
  *
  * This file is part of Celluloid.
  *
@@ -17,6 +17,7 @@
  * along with Celluloid.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
@@ -33,47 +34,44 @@ enum
 	PROP_COMPACT,
 	PROP_FULLSCREENED,
 	PROP_PAUSE,
-	PROP_SHOW_FULLSCREEN_BUTTON,
+	PROP_SHOW_PLAYLIST,
 	PROP_TIME_POSITION,
-	PROP_LOOP,
-	PROP_SHUFFLE,
 	PROP_VOLUME,
 	PROP_VOLUME_MAX,
 	PROP_VOLUME_POPUP_VISIBLE,
 	PROP_CHAPTER_LIST,
+	PROP_CONTENT_TITLE,
+	PROP_NARROW,
 	N_PROPERTIES
 };
 
 struct _CelluloidControlBox
 {
-	GtkBox parent_instance;
-
+	AdwBin parent_instance;
 	GtkGesture *click_gesture;
-
+	GtkWidget *clamp;
+	GtkWidget *title_widget;
+	GtkWidget *controls_box;
 	GtkWidget *inner_box;
 	GtkWidget *play_button;
-	GtkWidget *stop_button;
 	GtkWidget *forward_button;
 	GtkWidget *rewind_button;
 	GtkWidget *next_button;
 	GtkWidget *previous_button;
-	GtkWidget *loop_button;
-	GtkWidget *shuffle_button;
 	GtkWidget *volume_button;
 	GtkWidget *playlist_button;
-	GtkWidget *fullscreen_button;
 	GtkWidget *seek_bar;
 	GtkWidget *secondary_seek_bar;
 	gboolean skip_enabled;
 	gdouble duration;
 	gboolean enabled;
+	gboolean narrow;
 	gboolean compact;
 	gboolean fullscreened;
 	gboolean pause;
-	gboolean show_fullscreen_button;
+	gboolean show_playlist;
 	gdouble time_position;
-	gboolean loop;
-	gboolean shuffle;
+	const gchar *content_title;
 	gdouble volume;
 	gdouble volume_max;
 	gboolean volume_popup_visible;
@@ -82,7 +80,7 @@ struct _CelluloidControlBox
 
 struct _CelluloidControlBoxClass
 {
-	GtkBoxClass parent_class;
+	AdwBinClass parent_class;
 };
 
 static void
@@ -140,6 +138,9 @@ set_playing_state(CelluloidControlBox *box, gboolean playing);
 static void
 set_compact(CelluloidControlBox *box, gboolean compact);
 
+static void
+set_narrow(CelluloidControlBox *box, gboolean narrow);
+
 static void
 set_fullscreen_state(CelluloidControlBox *box, gboolean fullscreen);
 
@@ -148,7 +149,7 @@ init_button(	GtkWidget *button,
 		const gchar *icon_name,
 		const gchar *tooltip_text );
 
-G_DEFINE_TYPE(CelluloidControlBox, celluloid_control_box, GTK_TYPE_BOX)
+G_DEFINE_TYPE(CelluloidControlBox, celluloid_control_box, ADW_TYPE_BIN)
 
 static void
 set_property(	GObject *object,
@@ -174,6 +175,11 @@ set_property(	GObject *object,
 		set_enabled(self, self->enabled);
 		break;
 
+		case PROP_NARROW:
+		self->narrow = g_value_get_boolean(value);
+		set_narrow(self, self->narrow);
+		break;
+
 		case PROP_COMPACT:
 		self->compact = g_value_get_boolean(value);
 		set_compact(self, self->compact);
@@ -189,11 +195,8 @@ set_property(	GObject *object,
 		set_playing_state(self, !self->pause);
 		break;
 
-		case PROP_SHOW_FULLSCREEN_BUTTON:
-		self->show_fullscreen_button = g_value_get_boolean(value);
-		gtk_widget_set_visible
-			(	self->fullscreen_button,
-				self->show_fullscreen_button );
+		case PROP_SHOW_PLAYLIST:
+		self->show_playlist = g_value_get_boolean(value);
 		break;
 
 		case PROP_TIME_POSITION:
@@ -207,14 +210,6 @@ set_property(	GObject *object,
 				self->time_position );
 		break;
 
-		case PROP_LOOP:
-		self->loop = g_value_get_boolean(value);
-		break;
-
-		case PROP_SHUFFLE:
-		self->shuffle = g_value_get_boolean(value);
-		break;
-
 		case PROP_VOLUME:
 		self->volume = g_value_get_double(value);
 		break;
@@ -226,8 +221,7 @@ set_property(	GObject *object,
 		case PROP_VOLUME_POPUP_VISIBLE:
 		self->volume_popup_visible = g_value_get_boolean(value);
 
-		if(	self->volume_popup_visible &&
-			gtk_widget_is_visible(GTK_WIDGET(self)) )
+		if(self->volume_popup_visible)
 		{
 			g_signal_emit_by_name(self->volume_button, "popup");
 		}
@@ -241,6 +235,10 @@ set_property(	GObject *object,
 		self->chapter_list = g_value_get_pointer(value);
 		break;
 
+		case PROP_CONTENT_TITLE:
+		self->content_title = g_value_get_string(value);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -269,6 +267,10 @@ get_property(	GObject *object,
 		g_value_set_boolean(value, self->enabled);
 		break;
 
+		case PROP_NARROW:
+		g_value_set_boolean(value, self->narrow);
+		break;
+
 		case PROP_COMPACT:
 		g_value_set_boolean(value, self->compact);
 		break;
@@ -277,26 +279,18 @@ get_property(	GObject *object,
 		g_value_set_boolean(value, self->fullscreened);
 		break;
 
+		case PROP_SHOW_PLAYLIST:
+		g_value_set_boolean(value, self->show_playlist);
+		break;
+
 		case PROP_PAUSE:
 		g_value_set_boolean(value, self->pause);
 		break;
 
-		case PROP_SHOW_FULLSCREEN_BUTTON:
-		g_value_set_boolean(value, self->show_fullscreen_button);
-		break;
-
 		case PROP_TIME_POSITION:
 		g_value_set_double(value, self->time_position);
 		break;
 
-		case PROP_LOOP:
-		g_value_set_boolean(value, self->loop);
-		break;
-
-		case PROP_SHUFFLE:
-		g_value_set_boolean(value, self->shuffle);
-		break;
-
 		case PROP_VOLUME:
 		g_value_set_double(value, self->volume);
 		break;
@@ -313,6 +307,10 @@ get_property(	GObject *object,
 		g_value_set_pointer(value, self->chapter_list);
 		break;
 
+		case PROP_CONTENT_TITLE:
+		g_value_set_string(value, self->content_title);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -402,13 +400,11 @@ simple_signal_handler(GtkWidget *widget, gpointer data)
 	}
 	signal_map[]
 		= {	{box->play_button, "button-clicked", "play"},
-			{box->stop_button, "button-clicked", "stop"},
 			{box->forward_button, "button-clicked", "forward"},
 			{box->rewind_button, "button-clicked", "rewind"},
 			{box->previous_button, "button-clicked", "previous"},
 			{box->next_button, "button-clicked", "next"},
 			{box->playlist_button, "button-clicked", "playlist"},
-			{box->fullscreen_button, "button-clicked", "fullscreen"},
 			{NULL, NULL, NULL} };
 
 	for(i = 0; signal_map[i].name && signal_map[i].widget != widget; i++);
@@ -425,7 +421,6 @@ set_enabled(CelluloidControlBox *box, gboolean enabled)
 {
 	gtk_widget_set_sensitive(box->previous_button, enabled);
 	gtk_widget_set_sensitive(box->rewind_button, enabled);
-	gtk_widget_set_sensitive(box->stop_button, enabled);
 	gtk_widget_set_sensitive(box->play_button, enabled);
 	gtk_widget_set_sensitive(box->forward_button, enabled);
 	gtk_widget_set_sensitive(box->next_button, enabled);
@@ -465,31 +460,49 @@ set_compact(CelluloidControlBox *box, gboolean compact)
 	if(box->compact)
 	{
 		gtk_widget_set_halign(box->inner_box, GTK_ALIGN_CENTER);
-		gtk_widget_set_margin_start(box->loop_button, 12);
 		gtk_widget_set_visible(box->seek_bar, FALSE);
 		gtk_widget_set_visible(box->secondary_seek_bar, TRUE);
+
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "docked");
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
 	}
 	else
 	{
 		gtk_widget_set_halign(box->inner_box, GTK_ALIGN_FILL);
-		gtk_widget_set_margin_start(box->loop_button, 0);
 		gtk_widget_set_visible(box->seek_bar, TRUE);
 		gtk_widget_set_visible(box->secondary_seek_bar, FALSE);
+
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "docked");
+	}
+}
+
+static void
+set_narrow(CelluloidControlBox *box, gboolean narrow)
+{
+	if(box->narrow)
+	{
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "docked");
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
+	}
+	else
+	{
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "docked");
 	}
 }
 
 static void
 set_fullscreen_state(CelluloidControlBox *box, gboolean fullscreen)
 {
-	const gchar *icon_name =
-		fullscreen ?
-		"view-restore-symbolic" :
-		"view-fullscreen-symbolic";
-
-	gtk_button_set_icon_name
-		(GTK_BUTTON(box->fullscreen_button), icon_name);
-	gtk_widget_set_visible
-		(box->playlist_button, !fullscreen);
 }
 
 static void
@@ -498,8 +511,6 @@ init_button(	GtkWidget *button,
 		const gchar *tooltip_text )
 {
 	gtk_button_set_icon_name(GTK_BUTTON(button), icon_name);
-
-	g_object_set(button, "has-frame", FALSE, NULL);
 	gtk_widget_set_tooltip_text(button, tooltip_text);
 	gtk_widget_set_can_focus(button, FALSE);
 }
@@ -570,13 +581,12 @@ celluloid_control_box_class_init(CelluloidControlBoxClass *klass)
 		(object_class, PROP_PAUSE, pspec);
 
 	pspec = g_param_spec_boolean
-		(	"show-fullscreen-button",
-			"Show fullscreen button",
-			"Whether to show fullscreen button when applicable",
+		(	"show-playlist",
+			"Playlist shown",
+			"Whether the playlist panel is shown",
 			FALSE,
 			G_PARAM_READWRITE );
-	g_object_class_install_property
-		(object_class, PROP_SHOW_FULLSCREEN_BUTTON, pspec);
+	g_object_class_install_property(object_class, PROP_SHOW_PLAYLIST, pspec);
 
 	pspec = g_param_spec_double
 		(	"time-position",
@@ -589,23 +599,13 @@ celluloid_control_box_class_init(CelluloidControlBoxClass *klass)
 	g_object_class_install_property
 		(object_class, PROP_TIME_POSITION, pspec);
 
-	pspec = g_param_spec_boolean
-		(	"loop",
-			"Loop",
-			"Whether or not the loop button is active",
-			FALSE,
+	pspec = g_param_spec_string
+		(	"content-title",
+			"Content Title",
+			"Title of the currently playing item",
+			NULL,
 			G_PARAM_READWRITE );
-	g_object_class_install_property
-		(object_class, PROP_LOOP, pspec);
-
-	pspec = g_param_spec_boolean
-		(	"shuffle",
-			"Shuffle",
-			"Whether or not the the shuffle button is active",
-			FALSE,
-			G_PARAM_READWRITE );
-	g_object_class_install_property
-		(object_class, PROP_SHUFFLE, pspec);
+	g_object_class_install_property(object_class, PROP_CONTENT_TITLE, pspec);
 
 	pspec = g_param_spec_double
 		(	"volume",
@@ -638,13 +638,12 @@ celluloid_control_box_class_init(CelluloidControlBoxClass *klass)
 		(object_class, PROP_CHAPTER_LIST, pspec);
 
 	pspec = g_param_spec_boolean
-		(	"volume-popup-visible",
-			"Volume popup visible",
-			"Whether or not the volume popup is visible",
+		(	"narrow",
+			"Narrow",
+			"Whether or not narrow mode is enabled",
 			FALSE,
 			G_PARAM_READWRITE );
-	g_object_class_install_property
-		(object_class, PROP_VOLUME_POPUP_VISIBLE, pspec);
+	g_object_class_install_property(object_class, PROP_NARROW, pspec);
 
 	g_signal_new(	"button-clicked",
 			G_TYPE_FROM_CLASS(klass),
@@ -684,39 +683,37 @@ celluloid_control_box_init(CelluloidControlBox *box)
 	GtkWidget *popup = NULL;
 	GtkAdjustment *adjustment = NULL;
 	const gchar *volume_icons[] =
-		{	"audio-volume-muted",
-			"audio-volume-high",
-			"audio-volume-low",
-			"audio-volume-medium",
+		{	"audio-volume-muted-symbolic",
+			"audio-volume-high-symbolic",
+			"audio-volume-low-symbolic",
+			"audio-volume-medium-symbolic",
 			NULL };
 
+	box->clamp = adw_clamp_new();
 	box->click_gesture = gtk_gesture_click_new();
-
+	box->title_widget = gtk_label_new("");
+	box->controls_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	box->inner_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	box->play_button = gtk_button_new();
-	box->stop_button = gtk_button_new();
 	box->forward_button = gtk_button_new();
 	box->rewind_button = gtk_button_new();
 	box->next_button = gtk_button_new();
 	box->previous_button = gtk_button_new();
-	box->playlist_button = gtk_button_new();
-	box->fullscreen_button = gtk_button_new();
-	box->loop_button = gtk_toggle_button_new();
-	box->shuffle_button = gtk_toggle_button_new();
+	box->playlist_button = gtk_toggle_button_new();
 	box->volume_button = gtk_scale_button_new(0.0, 1.0, 0.02, volume_icons);
 	box->seek_bar = celluloid_seek_bar_new();
 	box->secondary_seek_bar = celluloid_seek_bar_new();
 	box->skip_enabled = FALSE;
 	box->duration = 0.0;
 	box->enabled = TRUE;
+	box->narrow = FALSE;
 	box->compact = FALSE;
 	box->fullscreened = FALSE;
 	box->pause = TRUE;
-	box->show_fullscreen_button = FALSE;
+	box->show_playlist = FALSE;
 	box->time_position = 0.0;
-	box->loop = FALSE;
-	box->shuffle = FALSE;
 	box->volume = 0.0;
+	box->content_title = "";
 	box->volume_max = 100.0;
 	box->volume_popup_visible = FALSE;
 	box->chapter_list = NULL;
@@ -724,9 +721,6 @@ celluloid_control_box_init(CelluloidControlBox *box)
 	init_button(	box->play_button,
 			"media-playback-start-symbolic",
 			_("Play") );
-	init_button(	box->stop_button,
-			"media-playback-stop-symbolic",
-			_("Stop") );
 	init_button(	box->forward_button,
 			"media-seek-forward-symbolic",
 			_("Forward") );
@@ -735,27 +729,27 @@ celluloid_control_box_init(CelluloidControlBox *box)
 			_("Rewind") );
 	init_button(	box->next_button,
 			"media-skip-forward-symbolic",
-			_("Next Chapter") );
+			_("Next Track") );
 	init_button(	box->previous_button,
 			"media-skip-backward-symbolic",
-			_("Previous Chapter") );
-	init_button(	box->loop_button,
-			"media-playlist-repeat-symbolic",
-			_("Loop Playlist") );
-	init_button(	box->shuffle_button,
-			"media-playlist-shuffle-symbolic",
-			_("Shuffle Playlist") );
+			_("Previous Track") );
 	init_button(	box->playlist_button,
 			"sidebar-show-right-symbolic",
-			_("Toggle Playlist") );
-	init_button(	box->fullscreen_button,
-			"view-fullscreen-symbolic",
-			_("Toggle Fullscreen") );
+			_("Show Playlist") );
+
+	gtk_widget_add_css_class(box->controls_box,"control-box");
+	gtk_widget_add_css_class(box->controls_box, "toolbar");
+	gtk_widget_add_css_class(box->title_widget, "heading");
 
 	gtk_widget_add_controller
 		(GTK_WIDGET(box), GTK_EVENT_CONTROLLER(box->click_gesture));
 
-	gtk_widget_add_css_class(GTK_WIDGET(box), "toolbar");
+	gtk_label_set_max_width_chars
+		(GTK_LABEL(box->title_widget), 20);
+	gtk_label_set_ellipsize
+		(GTK_LABEL(box->title_widget), PANGO_ELLIPSIZE_MIDDLE);
+	gtk_widget_set_size_request
+		(GTK_WIDGET(box->title_widget), 200, -1);
 
 	gtk_widget_set_margin_end(box->seek_bar, 6);
 	gtk_widget_set_margin_end(box->secondary_seek_bar, 6);
@@ -769,27 +763,28 @@ celluloid_control_box_init(CelluloidControlBox *box)
 
 	g_object_set(box->secondary_seek_bar, "show-label", FALSE, NULL);
 
+	gtk_widget_set_tooltip_text(box->volume_button, _("Volume"));
+	set_narrow(box, box->narrow);
 	set_compact(box, box->compact);
 
-	g_object_set(box, "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+	// No need to set maximum size here. It will be set by
+	// celluloid_control_box_set_floating().
+	adw_bin_set_child(ADW_BIN(box), box->clamp);
+	adw_clamp_set_child(ADW_CLAMP(box->clamp), box->controls_box);
+	adw_clamp_set_tightening_threshold(ADW_CLAMP(box->clamp), 700);
 
 	box->inner_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-
-	gtk_box_append(GTK_BOX(box), box->secondary_seek_bar);
-	gtk_box_append(GTK_BOX(box), box->inner_box);
-
+	gtk_box_append(GTK_BOX(box->controls_box), box->title_widget);
+	gtk_box_append(GTK_BOX(box->controls_box), box->secondary_seek_bar);
+	gtk_box_append(GTK_BOX(box->controls_box), box->inner_box);
 	gtk_box_append(GTK_BOX(box->inner_box), box->previous_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->rewind_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->play_button);
-	gtk_box_append(GTK_BOX(box->inner_box), box->stop_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->forward_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->next_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->seek_bar);
-	gtk_box_append(GTK_BOX(box->inner_box), box->loop_button);
-	gtk_box_append(GTK_BOX(box->inner_box), box->shuffle_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->volume_button);
 	gtk_box_append(GTK_BOX(box->inner_box), box->playlist_button);
-	gtk_box_append(GTK_BOX(box->inner_box), box->fullscreen_button);
 
 	popup =	gtk_scale_button_get_popup
 		(GTK_SCALE_BUTTON(box->volume_button));
@@ -798,9 +793,6 @@ celluloid_control_box_init(CelluloidControlBox *box)
 
 	gtk_popover_set_position(GTK_POPOVER(popup), GTK_POS_TOP);
 
-	g_object_bind_property(	popup, "visible",
-				box, "volume-popup-visible",
-				G_BINDING_DEFAULT );
 	g_object_bind_property(	box, "duration",
 				box->seek_bar, "duration",
 				G_BINDING_DEFAULT );
@@ -822,15 +814,18 @@ celluloid_control_box_init(CelluloidControlBox *box)
 	g_object_bind_property(	box, "pause",
 				box->secondary_seek_bar, "pause",
 				G_BINDING_DEFAULT );
+	g_object_bind_property(	box, "show_playlist",
+				box->playlist_button, "active",
+				G_BINDING_BIDIRECTIONAL );
 	g_object_bind_property(	box, "enabled",
 				box->secondary_seek_bar, "enabled",
 				G_BINDING_DEFAULT );
-	g_object_bind_property(	box, "loop",
-				box->loop_button, "active",
-				G_BINDING_BIDIRECTIONAL );
-	g_object_bind_property(	box, "shuffle",
-				box->shuffle_button, "active",
+	g_object_bind_property(	box, "content-title",
+				box->title_widget, "label",
 				G_BINDING_BIDIRECTIONAL );
+	g_object_bind_property(	box->title_widget, "label",
+				box->title_widget, "tooltip-text",
+				G_BINDING_DEFAULT );
 	g_object_bind_property_full(	box->volume_button, "value",
 					box, "volume",
 					G_BINDING_BIDIRECTIONAL,
@@ -855,10 +850,6 @@ celluloid_control_box_init(CelluloidControlBox *box)
 				"clicked",
 				G_CALLBACK(simple_signal_handler),
 				box );
-	g_signal_connect(	box->stop_button,
-				"clicked",
-				G_CALLBACK(simple_signal_handler),
-				box );
 	g_signal_connect(	box->seek_bar,
 				"seek",
 				G_CALLBACK(seek_handler),
@@ -883,14 +874,6 @@ celluloid_control_box_init(CelluloidControlBox *box)
 				"clicked",
 				G_CALLBACK(simple_signal_handler),
 				box );
-	g_signal_connect(	box->playlist_button,
-				"clicked",
-				G_CALLBACK(simple_signal_handler),
-				box );
-	g_signal_connect(	box->fullscreen_button,
-				"clicked",
-				G_CALLBACK(simple_signal_handler),
-				box );
 	g_signal_connect(	box->volume_button,
 				"value-changed",
 				G_CALLBACK(volume_changed_handler),
@@ -938,7 +921,10 @@ celluloid_control_box_get_volume(CelluloidControlBox *box)
 gboolean
 celluloid_control_box_get_volume_popup_visible(CelluloidControlBox *box)
 {
-	return box->volume_popup_visible;
+	GtkWidget *toggle_button =
+		gtk_widget_get_first_child(box->volume_button);
+
+	return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_button));
 }
 
 void
@@ -946,24 +932,34 @@ celluloid_control_box_set_floating(CelluloidControlBox *box, gboolean floating)
 {
 	if(floating)
 	{
-		gtk_widget_add_css_class(GTK_WIDGET(box), "osd");
-
-		gtk_widget_set_margin_start(GTK_WIDGET(box), 12);
-		gtk_widget_set_margin_end(GTK_WIDGET(box), 12);
-		gtk_widget_set_margin_top(GTK_WIDGET(box), 12);
-		gtk_widget_set_margin_bottom(GTK_WIDGET(box), 12);
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
+		gtk_widget_add_css_class
+			(GTK_WIDGET(box->controls_box), "osd");
+		gtk_widget_set_visible
+			(GTK_WIDGET(box->title_widget), TRUE);
+		adw_clamp_set_maximum_size
+			(ADW_CLAMP(box->clamp), 1000);
 	}
 	else
 	{
-		gtk_widget_remove_css_class(GTK_WIDGET(box), "osd");
-
-		gtk_widget_set_margin_start(GTK_WIDGET(box), 0);
-		gtk_widget_set_margin_end(GTK_WIDGET(box), 0);
-		gtk_widget_set_margin_top(GTK_WIDGET(box), 0);
-		gtk_widget_set_margin_bottom(GTK_WIDGET(box), 0);
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "undocked");
+		gtk_widget_remove_css_class
+			(GTK_WIDGET(box->controls_box), "osd");
+		gtk_widget_set_visible
+			(GTK_WIDGET(box->title_widget), FALSE);
+		adw_clamp_set_maximum_size
+			(ADW_CLAMP(box->clamp), G_MAXINT);
 	}
 }
 
+void
+celluloid_control_box_set_title(CelluloidControlBox *box, gchar* title)
+{
+	gtk_label_set_label(GTK_LABEL(box->title_widget), title);
+}
+
 void
 celluloid_control_box_reset(CelluloidControlBox *box)
 {
