@@ -238,6 +238,9 @@ celluloid_controller_init(CelluloidController *controller);
 static void
 update_extra_mpv_options(CelluloidController *controller);
 
+static void
+inhibit_idle(CelluloidController *controller, gboolean inhibit);
+
 G_DEFINE_TYPE(CelluloidController, celluloid_controller, G_TYPE_OBJECT)
 
 static void
@@ -307,6 +310,8 @@ set_property(	GObject *object,
 			set_video_area_status
 				(self, CELLULOID_VIDEO_AREA_STATUS_PLAYING);
 		}
+
+		inhibit_idle(self, !self->idle);
 		break;
 
 		case PROP_USE_SKIP_BUTTONS_FOR_PLAYLIST:
@@ -375,6 +380,14 @@ dispose(GObject *object)
 
 	if(controller->view)
 	{
+		inhibit_idle(controller, FALSE);
+
+		gtk_widget_remove_controller
+			(	GTK_WIDGET(controller->view),
+				controller->key_controller );
+
+		celluloid_controller_input_disconnect_signals(controller);
+
 		celluloid_view_make_gl_context_current(controller->view);
 		g_clear_object(&controller->model);
 
@@ -558,11 +571,15 @@ is_active_handler(GObject *gobject, GParamSpec *pspec, gpointer data)
 	CelluloidView *view = CELLULOID_VIEW(gobject);
 	gboolean is_active = TRUE;
 
-	g_object_get(view, "is-active", &is_active, NULL);
-
-	if(!is_active)
+	// As of GTK 4.17.4 controller->model may be NULL on window close.
+	if(controller->model)
 	{
-		celluloid_model_reset_keys(controller->model);
+		g_object_get(view, "is-active", &is_active, NULL);
+
+		if(!is_active)
+		{
+			celluloid_model_reset_keys(controller->model);
+		}
 	}
 }
 
@@ -720,6 +737,14 @@ connect_signals(CelluloidController *controller)
 	g_object_bind_property(	controller->model, "disc-list",
 				controller->view, "disc-list",
 				G_BINDING_DEFAULT );
+	g_object_bind_property_full(	controller->view, "loop-file",
+					controller->model, "loop-file",
+					G_BINDING_BIDIRECTIONAL|
+					G_BINDING_SYNC_CREATE,
+					boolean_to_loop,
+					loop_to_boolean,
+					NULL,
+					NULL );
 	g_object_bind_property_full(	controller->view, "loop",
 					controller->model, "loop-playlist",
 					G_BINDING_BIDIRECTIONAL|
@@ -1323,6 +1348,37 @@ seek_handler(GtkButton *button, gdouble value, gpointer data)
 	celluloid_model_seek(CELLULOID_CONTROLLER(data)->model, value);
 }
 
+static void
+inhibit_idle(CelluloidController *controller, gboolean inhibit)
+{
+	GSettings *settings =
+		g_settings_new(CONFIG_ROOT);
+	GtkApplication *app =
+		GTK_APPLICATION(controller->app);
+	GtkWindow *main_window =
+		GTK_WINDOW(celluloid_view_get_main_window(controller->view));
+
+	if (	inhibit &&
+		controller->inhibit_cookie == 0 &&
+		g_settings_get_boolean(settings, "inhibit-idle") )
+	{
+		controller->inhibit_cookie =
+			gtk_application_inhibit
+				(	app,
+					main_window,
+					GTK_APPLICATION_INHIBIT_IDLE,
+					_("Playing") );
+	}
+	else if (!inhibit && controller->inhibit_cookie != 0)
+	{
+		gtk_application_uninhibit(app, controller->inhibit_cookie);
+
+		controller->inhibit_cookie = 0;
+	}
+
+	g_object_unref(settings);
+}
+
 static void
 celluloid_controller_class_init(CelluloidControllerClass *klass)
 {
@@ -1387,7 +1443,18 @@ celluloid_controller_class_init(CelluloidControllerClass *klass)
 static void
 celluloid_controller_init(CelluloidController *controller)
 {
-	controller->key_controller = gtk_event_controller_key_new();
+	const GtkEventControllerScrollFlags scroll_flags =
+		GTK_EVENT_CONTROLLER_SCROLL_BOTH_AXES |
+		GTK_EVENT_CONTROLLER_SCROLL_DISCRETE;
+
+	controller->key_controller =
+		gtk_event_controller_key_new();
+	controller->motion_controller =
+		gtk_event_controller_motion_new();
+	controller->scroll_controller =
+		gtk_event_controller_scroll_new(scroll_flags);
+	controller->click_gesture =
+		gtk_gesture_click_new();
 
 	gtk_event_controller_set_propagation_phase
 		(controller->key_controller, GTK_PHASE_CAPTURE);
@@ -1403,6 +1470,7 @@ celluloid_controller_init(CelluloidController *controller)
 	controller->skip_buttons_binding = NULL;
 	controller->settings = g_settings_new(CONFIG_ROOT);
 	controller->mpris = NULL;
+	controller->inhibit_cookie = 0;
 }
 
 static void
