@@ -94,6 +94,9 @@ set_cursor_visible(CelluloidVideoArea *area, gboolean visible);
 static void
 reveal_controls(CelluloidVideoArea *area);
 
+static void
+compacted_apply_handler(AdwBreakpoint *self, gpointer data);
+
 static void
 destroy_handler(GtkWidget *widget, gpointer data);
 
@@ -203,6 +206,26 @@ reveal_controls(CelluloidVideoArea *area)
 					area );
 }
 
+static void
+compacted_apply_handler(AdwBreakpoint *self, gpointer data)
+{
+	CelluloidVideoArea *area = CELLULOID_VIDEO_AREA(data);
+	int minimum_width = 0;
+
+	gtk_widget_measure(	area->toolbar_view,
+				GTK_ORIENTATION_HORIZONTAL,
+				-1,
+				&minimum_width,
+				NULL,
+				NULL,
+				NULL );
+
+	gtk_widget_set_size_request
+		(GTK_WIDGET(area), minimum_width, 200);
+	gtk_widget_set_size_request
+		(GTK_WIDGET(area->toolbar_view), minimum_width, 200);
+}
+
 static void
 destroy_handler(GtkWidget *widget, gpointer data)
 {
@@ -442,6 +465,8 @@ celluloid_video_area_class_init(CelluloidVideoAreaClass *klass)
 static void
 celluloid_video_area_init(CelluloidVideoArea *area)
 {
+	GSettings *settings = g_settings_new(CONFIG_ROOT);
+
 	area->toast_overlay = adw_toast_overlay_new();
 	area->stack = gtk_stack_new();
 	area->gl_area = gtk_gl_area_new();
@@ -462,6 +487,14 @@ celluloid_video_area_init(CelluloidVideoArea *area)
 	area->use_floating_header_bar = FALSE;
 	area->use_floating_controls = FALSE;
 
+	const gboolean enable_graphics_offload =
+		g_settings_get_boolean(settings, "graphics-offload-enable");
+	gtk_graphics_offload_set_enabled
+		(	GTK_GRAPHICS_OFFLOAD(area->graphics_offload),
+			enable_graphics_offload ?
+			GTK_GRAPHICS_OFFLOAD_ENABLED :
+			GTK_GRAPHICS_OFFLOAD_DISABLED );
+
 	AdwBreakpointCondition *wide_condition =
 		adw_breakpoint_condition_new_length
 		(ADW_BREAKPOINT_CONDITION_MIN_WIDTH, 700, ADW_LENGTH_UNIT_SP);
@@ -477,6 +510,11 @@ celluloid_video_area_init(CelluloidVideoArea *area)
 		(ADW_BREAKPOINT_CONDITION_MAX_WIDTH, 400, ADW_LENGTH_UNIT_SP);
 	area->compacted = adw_breakpoint_new(compacted_condition);
 
+	g_signal_connect(	area->compacted,
+				"apply",
+				G_CALLBACK(compacted_apply_handler),
+				area );
+
 	adw_toolbar_view_set_reveal_top_bars
 		(	ADW_TOOLBAR_VIEW(area->toolbar_view),
 			area->use_floating_header_bar );
