@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 gnome-mpv
+ * Copyright (c) 2015-2019, 2021 gnome-mpv
  *
  * This file is part of Celluloid.
  *
@@ -31,6 +31,19 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE(CelluloidMpris, celluloid_mpris, CELLULOID, MPRIS, GObject)
 
+#define CELLULOID_MPRIS_ERROR celluloid_mpris_error_quark()
+
+enum
+{
+	CELLULOID_MPRIS_ERROR_UNKNOWN_METHOD,
+	CELLULOID_MPRIS_ERROR_UNKNOWN_PROPERTY,
+	CELLULOID_MPRIS_ERROR_SET_READONLY,
+	CELLULOID_MPRIS_ERROR_FAILED
+};
+
+GQuark
+celluloid_mpris_error_quark(void);
+
 GVariant *
 celluloid_mpris_build_g_variant_string_array(const gchar** list);
 
